@@ -435,6 +435,8 @@ gail_notebook_page_ref_state_set (AtkObject *accessible)
       if (atk_state_set_contains_state (state_set, ATK_STATE_VISIBLE))
         {
           atk_state_set_add_state (merged_state_set, ATK_STATE_VISIBLE);
+          if (atk_state_set_contains_state (state_set, ATK_STATE_ENABLED))
+              atk_state_set_add_state (merged_state_set, ATK_STATE_ENABLED);
           if (atk_state_set_contains_state (state_set, ATK_STATE_SHOWING))
               atk_state_set_add_state (merged_state_set, ATK_STATE_SHOWING);
 
